function varargout = ColorDialog(varargin)
% COLORDIALOG M-file for ColorDialog.fig
%      COLORDIALOG by itself, creates a new COLORDIALOG or raises the
%      existing singleton*.
%
%      H = COLORDIALOG returns the handle to a new COLORDIALOG or the handle to
%      the existing singleton*.
%
%      COLORDIALOG('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in COLORDIALOG.M with the given input arguments.
%
%      COLORDIALOG('Property','Value',...) creates a new COLORDIALOG or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before ColorDialog_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to ColorDialog_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help ColorDialog

% Last Modified by GUIDE v2.5 07-Aug-2005 23:45:13

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @ColorDialog_OpeningFcn, ...
                   'gui_OutputFcn',  @ColorDialog_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT

% --- Executes just before ColorDialog is made visible.
function ColorDialog_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to ColorDialog (see VARARGIN)


handles.current.choose_range_flag  = varargin{1};
handles.current.choose_range_max   = varargin{2};
handles.current.choose_range_min   = varargin{3};
handles.current.colormap           = varargin{4};
handles.imdata                     = varargin{5};

handles.choose_range_flag  = handles.current.choose_range_flag;
handles.choose_range_max   = handles.current.choose_range_max;
handles.choose_range_min   = handles.current.choose_range_min;
handles.colormap           = handles.current.colormap ;


guidata(hObject, handles);

init_dialog(hObject, eventdata, handles, varargin);

% Choose default command line output for ColorDialog
% handles.output = 'Yes';

% Update handles structure
% guidata(hObject, handles);

% Insert custom Title and Text if specified by the user
% Hint: when choosing keywords, be sure they are not easily confused 
% with existing figure properties.  See the output of set(figure) for
% a list of figure properties.
% if(nargin > 3)
%     for index = 1:2:(nargin-3),
%         if nargin-3==index, break, end
%         switch lower(varargin{index})
%          case 'title'
%           set(hObject, 'Name', varargin{index+1});
%          case 'string'
%           set(handles.text1, 'String', varargin{index+1});
%         end
%     end
% end

% Determine the position of the dialog - centered on the callback figure
% if available, else, centered on the screen
FigPos=get(0,'DefaultFigurePosition');
OldUnits = get(hObject, 'Units');
set(hObject, 'Units', 'pixels');
OldPos = get(hObject,'Position');
FigWidth = OldPos(3);
FigHeight = OldPos(4);
if isempty(gcbf)
    ScreenUnits=get(0,'Units');
    set(0,'Units','pixels');
    ScreenSize=get(0,'ScreenSize');
    set(0,'Units',ScreenUnits);

    FigPos(1)=1/2*(ScreenSize(3)-FigWidth);
    FigPos(2)=2/3*(ScreenSize(4)-FigHeight);
else
    GCBFOldUnits = get(gcbf,'Units');
    set(gcbf,'Units','pixels');
    GCBFPos = get(gcbf,'Position');
    set(gcbf,'Units',GCBFOldUnits);
    FigPos(1:2) = [(GCBFPos(1) + GCBFPos(3) / 2) - FigWidth / 2, ...
                   (GCBFPos(2) + GCBFPos(4) / 2) - FigHeight / 2];
end
FigPos(3:4)=[FigWidth FigHeight];
set(hObject, 'Position', FigPos);
set(hObject, 'Units', OldUnits);



% Make the GUI modal
set(handles.figure1,'WindowStyle','modal')

% UIWAIT makes ColorDialog wait for user response (see UIRESUME)
uiwait(handles.figure1);

% --- Outputs from this function are returned to the command line.
function varargout = ColorDialog_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.current.choose_range_flag;
varargout{2} = handles.current.choose_range_max;
varargout{3} = handles.current.choose_range_min;
varargout{4} = handles.current.colormap;



% The figure can be deleted now
delete(handles.figure1);

% --- Executes on button press in OkButton.
function OkButton_Callback(hObject, eventdata, handles)
% hObject    handle to OkButton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

handles.current.choose_range_flag  = handles.choose_range_flag             ;
handles.current.choose_range_max   = handles.choose_range_max     ;
handles.current.choose_range_min   = handles.choose_range_min             ;
handles.current.colormap           = handles.colormap;

guidata(hObject, handles);

% Use UIRESUME instead of delete because the OutputFcn needs
% to get the updated handles structure.
uiresume(handles.figure1);




% --- Executes on button press in CancelButton.
function CancelButton_Callback(hObject, eventdata, handles)
% hObject    handle to CancelButton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

uiresume(handles.figure1);



function ChooseRangeMaxEdit_Callback(hObject, eventdata, handles)
% hObject    handle to ChooseRangeMaxEdit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of ChooseRangeMaxEdit as text
%        str2double(get(hObject,'String')) returns contents of ChooseRangeMaxEdit as a double



choose_range_max = str2double(get(hObject, 'String'));
if isnan(choose_range_max)
    errordlg('Input must be a number','Error');
    set(handles.ChooseRangeMaxEdit,        'String',sprintf('%g',  handles.choose_range_max));
elseif choose_range_max < handles.choose_range_min
    errordlg('Max must be greater than min.','Error');
    set(handles.ChooseRangeMaxEdit,        'String',sprintf('%g',  handles.choose_range_max));
else
    handles.choose_range_max = choose_range_max;
    guidata(hObject, handles);
    set(handles.ChooseRangeMaxEdit,        'String',sprintf('%g',  handles.choose_range_max));
end;


% --- Executes during object creation, after setting all properties.
function ChooseRangeMaxEdit_CreateFcn(hObject, eventdata, handles)
% hObject    handle to ChooseRangeMaxEdit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function ChooseRangeMinEdit_Callback(hObject, eventdata, handles)
% hObject    handle to ChooseRangeMaxEdit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of ChooseRangeMaxEdit as text
%        str2double(get(hObject,'String')) returns contents of ChooseRangeMaxEdit as a double



choose_range_min = str2double(get(hObject, 'String'));
if isnan(choose_range_min)
    errordlg('Input must be a number','Error');
    set(handles.ChooseRangeMinEdit,        'String',sprintf('%g',  handles.choose_range_min));
elseif choose_range_min > handles.choose_range_max
    errordlg('Min must be less than max.','Error');
    set(handles.ChooseRangeMinEdit,        'String',sprintf('%g',  handles.choose_range_min));
else
    handles.choose_range_min = choose_range_min;
    guidata(hObject, handles);
    set(handles.ChooseRangeMinEdit,        'String',sprintf('%g',  handles.choose_range_min));
end;


% --- Executes during object creation, after setting all properties.
function ChooseRangeMinEdit_CreateFcn(hObject, eventdata, handles)
% hObject    handle to ChooseRangeMaxEdit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end






function init_dialog(hObject, eventdata, handles, varargin)

if handles.choose_range_flag == 0
    set(handles.ChooseRangeToggle,'Value',0);
else
    set(handles.ChooseRangeToggle,'Value',1);
end

set(handles.ChooseRangeMaxEdit,     'String',sprintf('%g',handles.choose_range_max));
set(handles.ChooseRangeMinEdit,     'String',sprintf('%g',handles.choose_range_min));
%set(handles.InterpCellNumberEdit, 'String',handles.colormap);

set(handles.ChooseRangeToggle,'Min',0);
set(handles.ChooseRangeToggle,'Max',1);

imsize     = size(handles.imdata);
loopsize   = imsize(1);
vectorsize = imsize(2);
histvect   = zeros(loopsize*vectorsize,1);


for i = 1: loopsize;
    histvect((1+(i-1)*vectorsize):(i*vectorsize))= handles.imdata(i,:);
end;

hist(histvect,400);
xlabel('Intensity');
ylabel('number');


switch handles.colormap
    case 'default'
        value = 1;
    case 'gray'
        value = 2;
    case 'hot'
        value = 3;
    otherwise
        value = 1;
end;
set(handles.ColorMapPopup, 'Value', value);



% --- Executes on selection change in ColorMapPopup.
function ColorMapPopup_Callback(hObject, eventdata, handles)
% hObject    handle to ColorMapPopup (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns ColorMapPopup contents as cell array
%        contents{get(hObject,'Value')} returns selected item from ColorMapPopup



menunum = get(hObject, 'Value');
switch menunum
    case 1
        handles.colormap = 'default';
       % 'default'
    case 2
        handles.colormap = 'gray';
        %'gray'
    case 3
        handles.colormap = 'hot';
        %'hot'
end
guidata(hObject, handles);




% --- Executes during object creation, after setting all properties.
function ColorMapPopup_CreateFcn(hObject, eventdata, handles)
% hObject    handle to ColorMapPopup (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

set(hObject, 'String', {'default', 'gray', 'hot'});


% --- Executes on button press in ChooseRangeToggle.
function ChooseRangeToggle_Callback(hObject, eventdata, handles)
% hObject    handle to ChooseRangeToggle (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of ChooseRangeToggle

if get(hObject,'Value') == 0
    handles.choose_range_flag = 0;
else
    handles.choose_range_flag = 1;
end;

guidata(hObject, handles);

    
    
    
    


% --- Executes on selection change in ColorMapPopupM.
function ColorMapPopupM_Callback(hObject, eventdata, handles)
% hObject    handle to ColorMapPopupM (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns ColorMapPopupM contents as cell array
%        contents{get(hObject,'Value')} returns selected item from ColorMapPopupM


% --- Executes during object creation, after setting all properties.
function ColorMapPopupM_CreateFcn(hObject, eventdata, handles)
% hObject    handle to ColorMapPopupM (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


